// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "asset/AssetManager.hpp"
#include "poker/PokerPlayer.hpp"
#include "scene/components/Components.hpp"

namespace Dawn {
  class VNPenny {
    public:
      static std::vector<Asset*> getAssets(AssetManager *assMan) {
        return std::vector<Asset*>{
          assMan->get<TextureAsset>("texture_penny"),
          assMan->get<TilesetAsset>("tileset_penny")
        };
      }

      static SceneItem * create(Scene *scene) {
        auto item = scene->createSceneItem();

        auto meshRenderer = item->addComponent<MeshRenderer>();

        auto material = item->addComponent<Material>();
        auto asset = scene->game->assetManager.get<TextureAsset>("texture_penny");
        auto param = material->getShader()->getParameterByName("u_Text");
        material->textureValues[param] = &asset->texture;
        
        auto meshHost = item->addComponent<MeshHost>();
        auto tiledSprite = item->addComponent<TiledSprite>();
        tiledSprite->setTileset(&scene->game->assetManager.get<TilesetAsset>("tileset_penny")->tileset);
        tiledSprite->setSize(glm::vec2(2, 2));

        auto pokerPlayer = item->addComponent<PokerPlayer>();

        return item;
      }
  };
}